"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const assert = require("assert");
/**
 * Helper class for sending requests and notifications
 */
class Common {
    /**
     * Template method for sending requests and receiving the response
     * @param connection the message connection to SSP server
     * @param messageType type of the message being sent
     * @param payload parameters of the message being sent
     * @param timeout timeout in milliseconds
     * @param timeoutMessage error message in case of timeout
     */
    static sendSimpleRequest(connection, messageType, payload, timeout, timeoutMessage) {
        return new Promise((resolve, reject) => {
            const timer = setTimeout(() => {
                reject(new Error(timeoutMessage));
            }, timeout);
            return connection.sendRequest(messageType, payload).then(result => {
                clearTimeout(timer);
                resolve(result);
            });
        });
    }
    /**
     * Template method for sending notifications and synchronously waiting for a response by subscribing to an event
     * @param connection the message connection to SSP server
     * @param messageType type of the message being sent
     * @param payload parameters of the message being sent
     * @param emitter event emitter used to subscribe for the response event
     * @param eventId id/name of the response event to wait for
     * @param timeout timeout in milliseconds
     * @param timeoutMessage error message in case of timeout
     */
    static sendNotificationSync(connection, messageType, payload, emitter, eventId, timeout, timeoutMessage) {
        return new Promise((resolve, reject) => {
            const timer = setTimeout(() => {
                return reject(new Error(timeoutMessage));
            }, timeout);
            const listener = ((params) => {
                let equal = true;
                for (const key in params) {
                    if (payload[key] && params[key]) {
                        try {
                            assert.deepEqual(payload[key], params[key]);
                        }
                        catch (err) {
                            equal = false;
                            break;
                        }
                    }
                }
                if (equal) {
                    clearTimeout(timer);
                    emitter.removeListener(eventId, listener);
                    resolve(params);
                }
            });
            emitter.prependListener(eventId, listener);
            connection.sendNotification(messageType, payload);
        });
    }
    /**
     * Template method for sending simple notifications to the server
     * @param connection message connection to the server
     * @param messageType type of the notification being sent
     * @param payload payload (parameters) of the message being sent
     */
    static sendSimpleNotification(connection, messageType, payload) {
        connection.sendNotification(messageType, payload);
    }
}
exports.Common = Common;
/**
 * Error messages
 */
var ErrorMessages;
(function (ErrorMessages) {
    ErrorMessages.FINDBEANS_TIMEOUT = 'Failed to retrieve server beans in time';
    ErrorMessages.ADDPATH_TIMEOUT = 'Failed to add discovery path in time';
    ErrorMessages.REMOVEPATH_TIMEOUT = 'Failed to remove discovery path in time';
    ErrorMessages.GETPATHS_TIMEOUT = 'Failed to retrieve discovery paths in time';
    ErrorMessages.GETSERVERS_TIMEOUT = 'Failed to retrieve servers in time';
    ErrorMessages.GETREQUIREDATTRS_TIMEOUT = 'Failed to retrieve required server attributes in time';
    ErrorMessages.GETOPTIONALATTRS_TIMEOUT = 'Failed to retrieve optional server attributes in time';
    ErrorMessages.DELETESERVERSYNC_TIMEOUT = 'Failed to delete server in time';
    ErrorMessages.GETLAUNCHMODES_TIMEOUT = 'Failed to get launch modes in time';
    ErrorMessages.GETREQUIREDLAUNCHATTRS_TIMEOUT = 'Failed to get required launch attributes in time';
    ErrorMessages.GETOPTIONALLAUNCHATTRS_TIMEOUT = 'Failed to get optional launch attributes in time';
    ErrorMessages.GETLAUNCHCOMMAND_TIMEOUT = 'Failed to get launch command in time';
    ErrorMessages.SERVERSTARTINGBYCLIENT_TIMEOUT = 'Failed to notify of server starting in time';
    ErrorMessages.SERVERSTARTEDBYCLIENT_TIMEOUT = 'Failed to notify of server started in time';
    ErrorMessages.STARTSERVER_TIMEOUT = 'Failed to start server in time';
    ErrorMessages.STOPSERVER_TIMEOUT = 'Failed to stop server in time';
    ErrorMessages.CREATESERVER_TIMEOUT = 'Failed to create server in time';
})(ErrorMessages = exports.ErrorMessages || (exports.ErrorMessages = {}));
//# sourceMappingURL=common.js.map