/// <reference types="node" />
import { Protocol } from '../protocol/protocol';
import { MessageConnection } from 'vscode-jsonrpc';
import { EventEmitter } from 'events';
/**
 * Server discovery requests handler
 */
export declare class Discovery {
    private connection;
    private emitter;
    /**
     * Constructs a new discovery handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection: MessageConnection, emitter: EventEmitter);
    /**
     * Subscribes to notifications sent by the server
     */
    private listenToDiscoveryChanges();
    /**
     * Finds suitable servers in a directory
     * @param path path to the desired directory
     * @param timeout timeout in milliseconds
     */
    findServerBeans(path: string, timeout?: number): Promise<Protocol.ServerBean[]>;
    /**
     * Sends notification to the SSP to add a directory to its discovery paths.
     * 'discoveryPathAdded' event will be fired when a response notification is received
     * @param path path to the desired directory
     */
    addDiscoveryPathAsync(path: string): void;
    /**
     * Synchronously adds discovery path to SSP by sending a notification and then waiting for
     * 'discoveryPathAdded' event to be fired
     * @param path path to the desired directory
     * @param timeout timeout in milliseconds
     */
    addDiscoveryPathSync(path: string, timeout?: number): Promise<Protocol.DiscoveryPath>;
    /**
     * Sends notification to the SSP to remove a directory from its discovery paths.
     * 'discoveryPathRemoved' event will be fired when a response notification is received
     * @param path path to the desired directory or a DiscoveryPath object containing the given filepath
     */
    removeDiscoveryPathAsync(path: string | Protocol.DiscoveryPath): void;
    /**
     * Synchronously removes discovery path from SSP by sending a notification and then waiting for
     * 'discoveryPathRemoved' event to be fired
     * @param path path to the desired directory or a DiscoveryPath object containing the given filepath
     * @param timeout timeout in milliseconds
     */
    removeDiscoveryPathSync(path: string | Protocol.DiscoveryPath, timeout?: number): Promise<Protocol.DiscoveryPath>;
    /**
     * Retrieves all discovery paths from the SSP server
     * @param timeout timeout in milliseconds
     */
    getDiscoveryPaths(timeout?: number): Promise<Protocol.DiscoveryPath[]>;
}
