"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const messages_1 = require("../protocol/messages");
const common_1 = require("./common");
/**
 * Server discovery requests handler
 */
class Discovery {
    /**
     * Constructs a new discovery handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection, emitter) {
        this.connection = connection;
        this.emitter = emitter;
        this.listenToDiscoveryChanges();
    }
    /**
     * Subscribes to notifications sent by the server
     */
    listenToDiscoveryChanges() {
        this.connection.onNotification(messages_1.Messages.Client.DiscoveryPathAddedNotification.type, discoveryPath => {
            this.emitter.emit('discoveryPathAdded', discoveryPath);
        });
        this.connection.onNotification(messages_1.Messages.Client.DiscoveryPathRemovedNotification.type, discoveryPath => {
            this.emitter.emit('discoveryPathRemoved', discoveryPath);
        });
    }
    /**
     * Finds suitable servers in a directory
     * @param path path to the desired directory
     * @param timeout timeout in milliseconds
     */
    findServerBeans(path, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.FindServerBeansRequest.type, { filepath: path }, timeout, common_1.ErrorMessages.FINDBEANS_TIMEOUT);
    }
    /**
     * Sends notification to the SSP to add a directory to its discovery paths.
     * 'discoveryPathAdded' event will be fired when a response notification is received
     * @param path path to the desired directory
     */
    addDiscoveryPathAsync(path) {
        common_1.Common.sendSimpleNotification(this.connection, messages_1.Messages.Server.AddDiscoveryPathNotification.type, { filepath: path });
    }
    /**
     * Synchronously adds discovery path to SSP by sending a notification and then waiting for
     * 'discoveryPathAdded' event to be fired
     * @param path path to the desired directory
     * @param timeout timeout in milliseconds
     */
    addDiscoveryPathSync(path, timeout = 2000) {
        const discoveryPath = { filepath: path };
        return common_1.Common.sendNotificationSync(this.connection, messages_1.Messages.Server.AddDiscoveryPathNotification.type, discoveryPath, this.emitter, 'discoveryPathAdded', timeout, common_1.ErrorMessages.ADDPATH_TIMEOUT);
    }
    /**
     * Sends notification to the SSP to remove a directory from its discovery paths.
     * 'discoveryPathRemoved' event will be fired when a response notification is received
     * @param path path to the desired directory or a DiscoveryPath object containing the given filepath
     */
    removeDiscoveryPathAsync(path) {
        if (typeof (path) === 'string') {
            path = { filepath: path };
        }
        common_1.Common.sendSimpleNotification(this.connection, messages_1.Messages.Server.RemoveDiscoveryPathNotification.type, path);
    }
    /**
     * Synchronously removes discovery path from SSP by sending a notification and then waiting for
     * 'discoveryPathRemoved' event to be fired
     * @param path path to the desired directory or a DiscoveryPath object containing the given filepath
     * @param timeout timeout in milliseconds
     */
    removeDiscoveryPathSync(path, timeout = 2000) {
        if (typeof (path) === 'string') {
            path = { filepath: path };
        }
        return common_1.Common.sendNotificationSync(this.connection, messages_1.Messages.Server.RemoveDiscoveryPathNotification.type, path, this.emitter, 'discoveryPathRemoved', timeout, common_1.ErrorMessages.REMOVEPATH_TIMEOUT);
    }
    /**
     * Retrieves all discovery paths from the SSP server
     * @param timeout timeout in milliseconds
     */
    getDiscoveryPaths(timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetDiscoveryPathsRequest.type, null, timeout, common_1.ErrorMessages.GETPATHS_TIMEOUT);
    }
}
exports.Discovery = Discovery;
//# sourceMappingURL=discovery.js.map