/// <reference types="node" />
import { MessageConnection } from 'vscode-jsonrpc';
import { Protocol } from '../protocol/protocol';
import { EventEmitter } from 'events';
/**
 * Server launching handler
 */
export declare class ServerLauncher {
    private connection;
    private emitter;
    /**
     * Constructs a new server launch handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection: MessageConnection, emitter: EventEmitter);
    /**
     * Subscribes to server process notifications
     */
    private listenToServerChanges();
    /**
     * Retrieves possible launch modes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getLaunchModes(serverType: Protocol.ServerType, timeout?: number): Promise<Protocol.ServerLaunchMode[]>;
    /**
     * Retrieves required launch attributes for a given server
     * @param launchAttrRequest object containing id and launch mode of a server, see {@link Protocol.LaunchAttributesRequest}
     * @param timeout timeout in milliseconds
     */
    getRequiredLaunchAttributes(launchAttrRequest: Protocol.LaunchAttributesRequest, timeout?: number): Promise<Protocol.Attributes>;
    /**
     * Retrieves optional launch attributes for a given server
     * @param launchAttrRequest object containing id and launch mode of a server, see {@link Protocol.LaunchAttributesRequest}
     * @param timeout timeout in milliseconds
     */
    getOptionalLaunchAttributes(launchAttrRequest: Protocol.LaunchAttributesRequest, timeout?: number): Promise<Protocol.Attributes>;
    /**
     * Retrieves launch command for a given server to be used in a CLI
     * @param launchParameters object containing the given server attributes for launching, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    getLaunchCommand(launchParameters: Protocol.LaunchParameters, timeout?: number): Promise<Protocol.CommandLineDetails>;
    /**
     * Notifies the SSP a server is being started manually by the client
     * @param startingAttributes launch parameters, set the 'initiatePolling' property to allow SSP to manage the server's state,
     * see {@link Protocol.ServerStartingAttributes}
     * @param timeout timeout in milliseconds
     */
    serverStartingByClient(startingAttributes: Protocol.ServerStartingAttributes, timeout?: number): Promise<Protocol.Status>;
    /**
     * Notifies the SSP a server has been started manually by the client
     * @param launchPatameters parameters the server has been started with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    serverStartedByClient(launchParameters: Protocol.LaunchParameters, timeout?: number): Promise<Protocol.Status>;
    /**
     * Sends a request to start the given server. Subscribe to the 'serverStateChanged' event
     * to monitor the server's state changes
     * @param launchParameters parameters to start the server with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    startServerAsync(launchParameters: Protocol.LaunchParameters, timeout?: number): Promise<Protocol.Status>;
    /**
     * Sends a request to start the given server and waits for 'serverStateChanged' event
     * until the server's state has changed to 'started'
     * @param launchParameters parameters to start the server with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    startServerSync(launchParameters: Protocol.LaunchParameters, timeout?: number): Promise<Protocol.ServerStateChange>;
    /**
     * Sends a request to stop the given server. Subscribe to the 'serverStateChanged' event
     * to monitor the server's state changes
     * @param stopParameters server stopping parameters, set force to 'true' to force shutdown, see {@link Protocol.StopServerAttributes}
     * @param timeout timeout in milliseconds
     */
    stopServerAsync(stopParameters: Protocol.StopServerAttributes, timeout?: number): Promise<Protocol.Status>;
    /**
     * Sends a request to stop the given server and waits for 'serverStateChanged' event
     * until the server's state has changed to 'stopped'
     * @param stopParameters server stopping parameters, set force to 'true' to force shutdown, see {@link Protocol.StopServerAttributes}
     * @param timeout timeout in milliseconds
     */
    stopServerSync(stopParameters: Protocol.StopServerAttributes, timeout?: number): Promise<Protocol.ServerStateChange>;
}
