"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const messages_1 = require("../protocol/messages");
const serverState_1 = require("../protocol/serverState");
const common_1 = require("./common");
/**
 * Server launching handler
 */
class ServerLauncher {
    /**
     * Constructs a new server launch handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection, emitter) {
        this.connection = connection;
        this.emitter = emitter;
        this.listenToServerChanges();
    }
    /**
     * Subscribes to server process notifications
     */
    listenToServerChanges() {
        this.connection.onNotification(messages_1.Messages.Client.ServerProcessCreatedNotification.type, process => {
            this.emitter.emit('serverProcessCreated', process);
        });
        this.connection.onNotification(messages_1.Messages.Client.ServerProcessOutputAppendedNotification.type, output => {
            this.emitter.emit('serverOutputAppended', output);
        });
        this.connection.onNotification(messages_1.Messages.Client.ServerProcessTerminatedNotification.type, process => {
            this.emitter.emit('serverProcessTerminated', process);
        });
        this.connection.onNotification(messages_1.Messages.Client.ServerAttributesChangedNotification.type, handle => {
            this.emitter.emit('serverAttributesChanged', handle);
        });
        this.connection.onNotification(messages_1.Messages.Client.ServerStateChangedNotification.type, state => {
            this.emitter.emit('serverStateChanged', state);
        });
    }
    /**
     * Retrieves possible launch modes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getLaunchModes(serverType, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetLaunchModesRequest.type, serverType, timeout, common_1.ErrorMessages.GETLAUNCHMODES_TIMEOUT);
    }
    /**
     * Retrieves required launch attributes for a given server
     * @param launchAttrRequest object containing id and launch mode of a server, see {@link Protocol.LaunchAttributesRequest}
     * @param timeout timeout in milliseconds
     */
    getRequiredLaunchAttributes(launchAttrRequest, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetRequiredLaunchAttributesRequest.type, launchAttrRequest, timeout, common_1.ErrorMessages.GETREQUIREDLAUNCHATTRS_TIMEOUT);
    }
    /**
     * Retrieves optional launch attributes for a given server
     * @param launchAttrRequest object containing id and launch mode of a server, see {@link Protocol.LaunchAttributesRequest}
     * @param timeout timeout in milliseconds
     */
    getOptionalLaunchAttributes(launchAttrRequest, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetOptionalLaunchAttributesRequest.type, launchAttrRequest, timeout, common_1.ErrorMessages.GETOPTIONALLAUNCHATTRS_TIMEOUT);
    }
    /**
     * Retrieves launch command for a given server to be used in a CLI
     * @param launchParameters object containing the given server attributes for launching, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    getLaunchCommand(launchParameters, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetLaunchCommandRequest.type, launchParameters, timeout, common_1.ErrorMessages.GETLAUNCHCOMMAND_TIMEOUT);
    }
    /**
     * Notifies the SSP a server is being started manually by the client
     * @param startingAttributes launch parameters, set the 'initiatePolling' property to allow SSP to manage the server's state,
     * see {@link Protocol.ServerStartingAttributes}
     * @param timeout timeout in milliseconds
     */
    serverStartingByClient(startingAttributes, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.ServerStartingByClientRequest.type, startingAttributes, timeout, common_1.ErrorMessages.SERVERSTARTINGBYCLIENT_TIMEOUT);
    }
    /**
     * Notifies the SSP a server has been started manually by the client
     * @param launchPatameters parameters the server has been started with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    serverStartedByClient(launchParameters, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.ServerStartedByClientRequest.type, launchParameters, timeout, common_1.ErrorMessages.SERVERSTARTEDBYCLIENT_TIMEOUT);
    }
    /**
     * Sends a request to start the given server. Subscribe to the 'serverStateChanged' event
     * to monitor the server's state changes
     * @param launchParameters parameters to start the server with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    startServerAsync(launchParameters, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.StartServerAsyncRequest.type, launchParameters, timeout, common_1.ErrorMessages.STARTSERVER_TIMEOUT);
    }
    /**
     * Sends a request to start the given server and waits for 'serverStateChanged' event
     * until the server's state has changed to 'started'
     * @param launchParameters parameters to start the server with, see {@link Protocol.LaunchParameters}
     * @param timeout timeout in milliseconds
     */
    startServerSync(launchParameters, timeout = 60000) {
        return new Promise((resolve, reject) => {
            const timer = setTimeout(() => {
                return reject(new Error(common_1.ErrorMessages.STARTSERVER_TIMEOUT));
            }, timeout);
            let result;
            const listener = (state) => {
                if (state.server.id === launchParameters.params.id && state.state === serverState_1.ServerState.STARTED) {
                    result.then(() => {
                        clearTimeout(timer);
                        this.emitter.removeListener('serverStateChanged', listener);
                        resolve(state);
                    });
                }
            };
            this.emitter.prependListener('serverStateChanged', listener);
            result = this.connection.sendRequest(messages_1.Messages.Server.StartServerAsyncRequest.type, launchParameters);
        });
    }
    /**
     * Sends a request to stop the given server. Subscribe to the 'serverStateChanged' event
     * to monitor the server's state changes
     * @param stopParameters server stopping parameters, set force to 'true' to force shutdown, see {@link Protocol.StopServerAttributes}
     * @param timeout timeout in milliseconds
     */
    stopServerAsync(stopParameters, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.StopServerAsyncRequest.type, stopParameters, timeout, common_1.ErrorMessages.STOPSERVER_TIMEOUT);
    }
    /**
     * Sends a request to stop the given server and waits for 'serverStateChanged' event
     * until the server's state has changed to 'stopped'
     * @param stopParameters server stopping parameters, set force to 'true' to force shutdown, see {@link Protocol.StopServerAttributes}
     * @param timeout timeout in milliseconds
     */
    stopServerSync(stopParameters, timeout = 60000) {
        return new Promise((resolve, reject) => {
            const timer = setTimeout(() => {
                return reject(new Error(common_1.ErrorMessages.STOPSERVER_TIMEOUT));
            }, timeout);
            let result;
            const listener = (state) => {
                if (state.server.id === stopParameters.id && state.state === serverState_1.ServerState.STOPPED) {
                    result.then(() => {
                        clearTimeout(timer);
                        this.emitter.removeListener('serverStateChanged', listener);
                        resolve(state);
                    });
                }
            };
            this.emitter.prependListener('serverStateChanged', listener);
            result = this.connection.sendRequest(messages_1.Messages.Server.StopServerAsyncRequest.type, stopParameters);
        });
    }
}
exports.ServerLauncher = ServerLauncher;
//# sourceMappingURL=serverLauncher.js.map