/// <reference types="node" />
import { MessageConnection } from 'vscode-jsonrpc';
import { Protocol } from '../protocol/protocol';
import { EventEmitter } from 'events';
/**
 * Server creation/removal handler
 */
export declare class ServerModel {
    private connection;
    private emitter;
    /**
     * Constructs a new server model handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection: MessageConnection, emitter: EventEmitter);
    /**
     * Subscribe to server creation and deletion events
     */
    private listenToServerChanges();
    /**
     * Sends a request to create a server from a given directory, subscribe to the 'serverAdded'
     * event to see when the server creation is finished
     * @param path path to the server's root directory
     * @param id unique identifier for the newly created server
     * @param timeout timeout in milliseconds
     */
    createServerFromPathAsync(path: string, id: string, timeout?: number): Promise<Protocol.Status>;
    /**
     * Sends a request to create a server from an existing ServerBean object, subscribe to the 'serverAdded'
     * event to see when the server creation is finished
     * @param serverBean ServerBean object
     * @param id unique identifier for the new server, if left empty, the serverBean.name will be used
     * @param timeout timeout in milliseconds
     */
    createServerFromBeanAsync(serverBean: Protocol.ServerBean, id?: string, timeout?: number): Promise<Protocol.Status>;
    /**
     * Sends a request to create a server from a given directory, then waits for the 'serverAdded'
     * event with the given id
     * @param path path to the server's root directory
     * @param id unique identifier for the newly created server
     * @param timeout timeout in milliseconds
     */
    createServerFromPath(path: string, id: string, timeout?: number): Promise<Protocol.ServerHandle>;
    /**
     * Sends a request to create a server from an existing ServerBean object,  then waits for the 'serverAdded'
     * event with the given id
     * @param serverBean ServerBean object
     * @param id unique identifier for the new server, if left empty, the serverBean.name will be used
     * @param timeout timeout in milliseconds
     */
    createServerFromBean(serverBean: Protocol.ServerBean, id?: string, timeout?: number): Promise<Protocol.ServerHandle>;
    /**
     * Sends notification to remove a server from SSP, then waits for the appropriate 'serverRemoved' event
     * @param serverHandle server handle containing the server id and type, see {@link Protocol.ServerHandle}
     * @param timeout timeout in milliseconds
     */
    deleteServerSync(serverHandle: Protocol.ServerHandle, timeout?: number): Promise<Protocol.ServerHandle>;
    /**
     * Sends notification to remove a server from SSP. Subscribe to the 'serverRemoved' event to see
     * when the removal finishes
     * @param serverHandle server handle containing the server id and type, see {@link Protocol.ServerHandle}
     */
    deleteServerAsync(serverHandle: Protocol.ServerHandle): void;
    /**
     * Retreives handles for all servers within SSP
     * @param timeout timeout in milliseconds
     */
    getServerHandles(timeout?: number): Promise<Protocol.ServerHandle[]>;
    /**
     * Retreives required attributes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getServerTypeRequiredAttributes(serverType: Protocol.ServerType, timeout?: number): Promise<Protocol.Attributes>;
    /**
     * Retreives optional attributes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getServerTypeOptionalAttributes(serverType: Protocol.ServerType, timeout?: number): Promise<Protocol.Attributes>;
}
