"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const messages_1 = require("../protocol/messages");
const common_1 = require("./common");
/**
 * Server creation/removal handler
 */
class ServerModel {
    /**
     * Constructs a new server model handler
     * @param connection message connection to the SSP
     * @param emitter event emitter to handle notification events
     */
    constructor(connection, emitter) {
        this.connection = connection;
        this.emitter = emitter;
        this.listenToServerChanges();
    }
    /**
     * Subscribe to server creation and deletion events
     */
    listenToServerChanges() {
        this.connection.onNotification(messages_1.Messages.Client.ServerAddedNotification.type, handle => {
            this.emitter.emit('serverAdded', handle);
        });
        this.connection.onNotification(messages_1.Messages.Client.ServerRemovedNotification.type, handle => {
            this.emitter.emit('serverRemoved', handle);
        });
    }
    /**
     * Sends a request to create a server from a given directory, subscribe to the 'serverAdded'
     * event to see when the server creation is finished
     * @param path path to the server's root directory
     * @param id unique identifier for the newly created server
     * @param timeout timeout in milliseconds
     */
    createServerFromPathAsync(path, id, timeout = 2000) {
        return __awaiter(this, void 0, void 0, function* () {
            const serverBeans = yield common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.FindServerBeansRequest.type, { filepath: path }, timeout / 2, common_1.ErrorMessages.FINDBEANS_TIMEOUT);
            const serverAttributes = {
                id: id,
                serverType: serverBeans[0].serverAdapterTypeId,
                attributes: {
                    'server.home.dir': serverBeans[0].location
                }
            };
            return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.CreateServerRequest.type, serverAttributes, timeout, common_1.ErrorMessages.CREATESERVER_TIMEOUT);
        });
    }
    /**
     * Sends a request to create a server from an existing ServerBean object, subscribe to the 'serverAdded'
     * event to see when the server creation is finished
     * @param serverBean ServerBean object
     * @param id unique identifier for the new server, if left empty, the serverBean.name will be used
     * @param timeout timeout in milliseconds
     */
    createServerFromBeanAsync(serverBean, id, timeout = 2000) {
        return __awaiter(this, void 0, void 0, function* () {
            const serverId = id ? id : serverBean.name;
            const serverAttributes = {
                id: serverId,
                serverType: serverBean.serverAdapterTypeId,
                attributes: {
                    'server.home.dir': serverBean.location
                }
            };
            return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.CreateServerRequest.type, serverAttributes, timeout, common_1.ErrorMessages.CREATESERVER_TIMEOUT);
        });
    }
    /**
     * Sends a request to create a server from a given directory, then waits for the 'serverAdded'
     * event with the given id
     * @param path path to the server's root directory
     * @param id unique identifier for the newly created server
     * @param timeout timeout in milliseconds
     */
    createServerFromPath(path, id, timeout = 2000) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const timer = setTimeout(() => {
                return reject(new Error(common_1.ErrorMessages.CREATESERVER_TIMEOUT));
            }, timeout);
            let result;
            const listener = (handle) => {
                if (handle.id === id) {
                    result.then(status => {
                        clearTimeout(timer);
                        this.emitter.removeListener('serverAdded', listener);
                        resolve(handle);
                    });
                }
            };
            this.emitter.prependListener('serverAdded', listener);
            const serverBeans = yield this.connection.sendRequest(messages_1.Messages.Server.FindServerBeansRequest.type, { filepath: path });
            const serverAttributes = {
                id: id,
                serverType: serverBeans[0].serverAdapterTypeId,
                attributes: {
                    'server.home.dir': serverBeans[0].location
                }
            };
            result = this.connection.sendRequest(messages_1.Messages.Server.CreateServerRequest.type, serverAttributes);
        }));
    }
    /**
     * Sends a request to create a server from an existing ServerBean object,  then waits for the 'serverAdded'
     * event with the given id
     * @param serverBean ServerBean object
     * @param id unique identifier for the new server, if left empty, the serverBean.name will be used
     * @param timeout timeout in milliseconds
     */
    createServerFromBean(serverBean, id, timeout = 2000) {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const serverId = id ? id : serverBean.name;
            const timer = setTimeout(() => {
                return reject(new Error(common_1.ErrorMessages.CREATESERVER_TIMEOUT));
            }, timeout);
            let result;
            const listener = (handle) => {
                if (handle.id === serverId) {
                    result.then(status => {
                        clearTimeout(timer);
                        this.emitter.removeListener('serverAdded', listener);
                        resolve(handle);
                    });
                }
            };
            this.emitter.prependListener('serverAdded', listener);
            const serverAttributes = {
                id: serverId,
                serverType: serverBean.serverAdapterTypeId,
                attributes: {
                    'server.home.dir': serverBean.location
                }
            };
            result = this.connection.sendRequest(messages_1.Messages.Server.CreateServerRequest.type, serverAttributes);
        }));
    }
    /**
     * Sends notification to remove a server from SSP, then waits for the appropriate 'serverRemoved' event
     * @param serverHandle server handle containing the server id and type, see {@link Protocol.ServerHandle}
     * @param timeout timeout in milliseconds
     */
    deleteServerSync(serverHandle, timeout = 2000) {
        return common_1.Common.sendNotificationSync(this.connection, messages_1.Messages.Server.DeleteServerNotification.type, serverHandle, this.emitter, 'serverRemoved', timeout, common_1.ErrorMessages.DELETESERVERSYNC_TIMEOUT);
    }
    /**
     * Sends notification to remove a server from SSP. Subscribe to the 'serverRemoved' event to see
     * when the removal finishes
     * @param serverHandle server handle containing the server id and type, see {@link Protocol.ServerHandle}
     */
    deleteServerAsync(serverHandle) {
        common_1.Common.sendSimpleNotification(this.connection, messages_1.Messages.Server.DeleteServerNotification.type, serverHandle);
    }
    /**
     * Retreives handles for all servers within SSP
     * @param timeout timeout in milliseconds
     */
    getServerHandles(timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetServerHandlesRequest.type, null, timeout, common_1.ErrorMessages.GETSERVERS_TIMEOUT);
    }
    /**
     * Retreives required attributes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getServerTypeRequiredAttributes(serverType, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetRequiredAttributesRequest.type, serverType, timeout, common_1.ErrorMessages.GETREQUIREDATTRS_TIMEOUT);
    }
    /**
     * Retreives optional attributes for a given server type
     * @param serverType object representing the server type, see {@link Protocol.ServerType}
     * @param timeout timeout in milliseconds
     */
    getServerTypeOptionalAttributes(serverType, timeout = 2000) {
        return common_1.Common.sendSimpleRequest(this.connection, messages_1.Messages.Server.GetOptionalAttributesRequest.type, serverType, timeout, common_1.ErrorMessages.GETOPTIONALATTRS_TIMEOUT);
    }
}
exports.ServerModel = ServerModel;
//# sourceMappingURL=serverModel.js.map